@@ -19,7 +19,7 @@ pub(super) fn prepare_rename(params: &RenameParams) -> Option<Span> {
     ))
 }
 
-pub(super) fn rename<'a>(builder: &mut RenameBuilder) -> Option<()> {
+pub(super) fn rename(builder: &mut RenameBuilder) -> Option<()> {
     let name = prepare_rename(&builder.params)?;
 
     for document in &builder.params.feature.project.documents {
@@ -35,7 +35,10 @@ pub(super) fn rename<'a>(builder: &mut RenameBuilder) -> Option<()> {
             }
         }
 
-        builder.result.changes.insert(*document, edits);
+        builder
+            .result
+            .changes
+            .insert(*document, edits.iter().map(|&x| x.into()).collect());
     }
 
     Some(())
