@@ -23,6 +23,7 @@ use notify_debouncer_full::{DebouncedEvent, Debouncer, RecommendedCache};
 use parking_lot::{Mutex, RwLock};
 use rustc_hash::FxHashSet;
 use serde::{de::DeserializeOwned, Serialize};
+use serde_json::{Map, Value};
 use threadpool::ThreadPool;
 
 use crate::{
@@ -174,6 +175,13 @@ impl Server {
                 ..Default::default()
             }),
             inlay_hint_provider: Some(OneOf::Left(true)),
+            experimental: Some(Value::Object(Map::from_iter(
+                [
+                    ("textDocumentBuild".to_string(), Value::Bool(true)),
+                    ("textDocumentForwardSearch".to_string(), Value::Bool(true)),
+                ]
+                .into_iter(),
+            ))),
             ..ServerCapabilities::default()
         }
     }
@@ -555,7 +563,10 @@ impl Server {
 
     fn goto_definition(&self, id: RequestId, mut params: GotoDefinitionParams) -> Result<()> {
         normalize_uri(&mut params.text_document_position_params.text_document.uri);
-        self.run_query(id, move |db| definition::goto_definition(db, params));
+        let client_flags = Arc::clone(&self.client_flags);
+        self.run_query(id, move |db| {
+            definition::goto_definition(db, params, &client_flags)
+        });
         Ok(())
     }
 
@@ -1072,6 +1083,7 @@ impl Server {
                     match msg? {
                         InternalMessage::SetDistro(distro) => {
                             self.workspace.write().set_distro(distro);
+                            self.update_workspace();
                         }
                         InternalMessage::SetOptions(options) => {
                             self.update_options(*options);
@@ -1101,9 +1113,20 @@ impl Server {
     }
 
     pub fn run(mut self, options: StartupOptions) -> Result<()> {
+        static NEXT_TOKEN: AtomicI32 = AtomicI32::new(1);
         if !options.skip_distro {
             let sender = self.internal_tx.clone();
+            let progress = self.client_flags.progress;
+            let client = self.client.clone();
+
             self.pool.execute(move || {
+                let progress_reporter = if progress {
+                    let token = NEXT_TOKEN.fetch_add(1, std::sync::atomic::Ordering::SeqCst);
+                    Some(ProgressReporter::new_inputs_progress(client.clone(), token))
+                } else {
+                    None
+                };
+
                 let distro = Distro::detect().unwrap_or_else(|why| {
                     log::warn!("Unable to load distro files: {}", why);
                     Distro::default()
@@ -1111,6 +1134,8 @@ impl Server {
 
                 log::info!("Detected distribution: {:?}", distro.kind);
                 sender.send(InternalMessage::SetDistro(distro)).unwrap();
+
+                drop(progress_reporter);
             });
         }
 
