@@ -191,13 +191,25 @@ pub fn diagnostic(
     })
 }
 
-pub fn inlay_hint(hint: InlayHint, line_index: &LineIndex) -> Option<lsp_types::InlayHint> {
+pub fn inlay_hint(
+    hint: InlayHint,
+    line_index: &LineIndex,
+    max_length: Option<usize>,
+) -> Option<lsp_types::InlayHint> {
     let position = line_index.line_col_lsp(hint.offset)?;
+    let trim_text = |text: &mut String| match max_length {
+        Some(max_length) if text.len() > max_length => {
+            text.truncate(max_length);
+            text.push('…');
+        }
+        _ => {}
+    };
+
     Some(match hint.data {
         InlayHintData::LabelDefinition(label) => {
             let number = label.number?;
 
-            let text = match &label.object {
+            let mut text = match &label.object {
                 RenderedObject::Section { prefix, .. } => {
                     format!("{} {}", prefix, number)
                 }
@@ -211,9 +223,11 @@ pub fn inlay_hint(hint: InlayHint, line_index: &LineIndex) -> Option<lsp_types::
                 RenderedObject::EnumItem => format!("Item {}", number),
             };
 
+            trim_text(&mut text);
+
             lsp_types::InlayHint {
                 position,
-                label: lsp_types::InlayHintLabel::String(format!(" {text} ")),
+                label: lsp_types::InlayHintLabel::String(format!(" {text} ",)),
                 kind: None,
                 text_edits: None,
                 tooltip: None,
@@ -223,7 +237,8 @@ pub fn inlay_hint(hint: InlayHint, line_index: &LineIndex) -> Option<lsp_types::
             }
         }
         InlayHintData::LabelReference(label) => {
-            let text = label.reference();
+            let mut text = label.reference();
+            trim_text(&mut text);
 
             lsp_types::InlayHint {
                 position,
@@ -365,6 +380,7 @@ pub fn symbol_kind(value: symbols::SymbolKind) -> lsp_types::SymbolKind {
             BibtexEntryTypeCategory::Collection => lsp_types::SymbolKind::TYPE_PARAMETER,
         },
         symbols::SymbolKind::Field => lsp_types::SymbolKind::FIELD,
+        symbols::SymbolKind::Environment => lsp_types::SymbolKind::FUNCTION,
     }
 }
 
@@ -396,8 +412,15 @@ pub fn workspace_edit(result: RenameResult, new_name: &str) -> lsp_types::Worksp
         let mut edits = Vec::new();
         ranges
             .into_iter()
-            .filter_map(|range| document.line_index.line_col_lsp_range(range))
-            .for_each(|range| edits.push(lsp_types::TextEdit::new(range, new_name.into())));
+            .filter_map(|info| {
+                document.line_index.line_col_lsp_range(info.range).map(|i| {
+                    (
+                        i,
+                        info.prefix.map_or(new_name.into(), |p| p + new_name.into()),
+                    )
+                })
+            })
+            .for_each(|(range, new_name)| edits.push(lsp_types::TextEdit::new(range, new_name)));
 
         changes.insert(document.uri.clone(), edits);
     }
@@ -424,7 +447,33 @@ pub fn document_highlight(
     Some(lsp_types::DocumentHighlight { range, kind })
 }
 
-pub fn hover(hover: Hover, line_index: &LineIndex) -> Option<lsp_types::Hover> {
+pub fn hover(
+    hover: Hover,
+    line_index: &LineIndex,
+    client_flags: &ClientFlags,
+) -> Option<lsp_types::Hover> {
+    fn inline_image(
+        command: &completion_data::Command,
+
+        client_flags: &ClientFlags,
+    ) -> Option<lsp_types::MarkupContent> {
+        let name = &command.name;
+        command
+            .image
+            .map(|base64| format!("![{name}](data:image/png;base64,{base64}|width=48,height=48)"))
+            .filter(|_| client_flags.hover_markdown)
+            .map(|value| lsp_types::MarkupContent {
+                kind: lsp_types::MarkupKind::Markdown,
+                value,
+            })
+            .or_else(|| {
+                Some(lsp_types::MarkupContent {
+                    kind: lsp_types::MarkupKind::PlainText,
+                    value: command.glyph.as_deref()?.into(),
+                })
+            })
+    }
+
     let contents = match hover.data {
         HoverData::Citation(text) => lsp_types::MarkupContent {
             kind: lsp_types::MarkupKind::Markdown,
@@ -434,6 +483,7 @@ pub fn hover(hover: Hover, line_index: &LineIndex) -> Option<lsp_types::Hover> {
             kind: lsp_types::MarkupKind::PlainText,
             value: description.into(),
         },
+        HoverData::Command(command) => inline_image(command, client_flags)?,
         HoverData::EntryType(type_) => lsp_types::MarkupContent {
             kind: lsp_types::MarkupKind::Markdown,
             value: type_.documentation?.into(),
